@@ -16,10 +16,10 @@ our @EXPORT_OK = qw(
     len         to_keys  to_vals     is_array
     is_hash     every    noop        identity
     is_empty    is_sub   flow        eql
-    to_pairs    for_each apply
+    to_pairs    for_each apply       get
 );
 
-our $VERSION = '0.16';
+our $VERSION = '0.19';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -35,6 +35,24 @@ sub identity {
     return $args;
 }
 
+sub get {
+    my $coll    = shift // [];
+    my $key     = shift // 0;
+    my $default = shift;
+
+    if (is_array($coll)) {
+        return defined $coll->[$key] ? $coll->[$key] : $default;
+    }
+
+    if (is_hash($coll)) {
+        return defined $coll->{$key} ? $coll->{$key} : $default;
+    }
+
+    my $string_coll = [spread($coll)];
+
+    return defined $string_coll->[$key] ? $string_coll->[$key] : $default;
+}
+
 sub apply {
     my $fn   = shift // sub {};
     my $args = shift // [];
@@ -487,7 +505,7 @@ concise code.
     len         to_keys    to_vals     is_array
     is_hash     every      noop        identity
     is_empty    is_sub     flow        eql
-    to_pairs    for_each   apply
+    to_pairs    for_each   apply       get
 
 =cut
 
@@ -895,6 +913,47 @@ Returns 1 if the argument is 'empty',
 
 =cut
 
+=head2 get
+
+Returns value from hash, string, array based on key/idx provided.
+Returns default value if provided key/idx does not exist on collection.
+Only works one level deep;
+
+    my $hash = {
+        key1 => 'value1',
+    };
+
+    get($hash, 'key1');
+
+    # 'value1'
+
+
+    my $array = [100, 200, 300]
+
+    get($array, 1);
+
+    # 200
+
+
+    my $string = "Hello";
+
+    get($string, 1);
+
+    # e
+
+
+    # Also has the ability to supply default-value when key/idx does not exist
+
+    my $hash = {
+        key1 => 'value1',
+    };
+
+    get($hash, 'key2', "DEFAULT HERE");
+
+    # 'DEFAULT HERE'
+
+=cut
+
 =head2 spread
 
 Destructures an array / hash into non-ref context.
@@ -975,6 +1034,7 @@ Creates an array of the values in a hash, of an array, or string.
 =cut
 
 =head2 to_pairs
+
 Creates an array of key-value, or idx-value pairs from arrays, hashes, and strings.
 If used on a hash, key-pair order can not be guaranteed;
 
